==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/messages/nl/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Zeker</strong> weten?',
    '<strong>Latest</strong> updates' => '<strong>Laatste</strong> updates',
    '<strong>Mail</strong> summary' => '<strong>E-mail</strong> samenvatting',
    'Account settings' => 'Accountinstellingen',
    'Actions' => 'Acties',
    'Add:' => 'Toevoegen:',
    'Administration' => 'Administratie',
    'All' => 'Allemaal',
    'Allow' => 'Toestaan',
    'An error occurred while handling your last action. (Handler not found).' => 'Een fout deed zich voor bij het afhandelen van uw laatste actie. (Handler niet gevonden).',
    'An unexpected error occurred while loading the search result.' => 'Een onverwachte fout deed zich voor tijdens het laden van het zoekresultaat.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Een onverwachte fout deed zich voor; neem bij herhaling contact op met een beheerder van deze site.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Een onbekende serverfout deed zich voor; neem bij herhaling contact op met een beheerder van deze site.',
    'An unknown error occurred while uploading.' => 'Een onverwachte fout deed zich voor tijdens het uploaden.',
    'An unknown error occurred while uploading. Hint: check your upload_max_filesize and post_max_size php settings.' => 'Een onverwachte fout deed zich voor tijdens het uploaden. Hint: controleer de «upload_max_filesize» en «post_max_size» php-instellingen.',
    'Back' => 'Terug',
    'Back to dashboard' => 'Terug naar het dashboard',
    'Cancel' => 'Annuleren',
    'Choose language:' => 'Kies een taal:',
    'Close' => 'Sluiten',
    'Collapse' => 'Inklappen',
    'Confirm' => 'Bevestig',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Content Addon bron moet een instantie van HActiveRecordContent of HActiveRecordContentAddon zijn!',
    'Copy to clipboard' => 'Kopieer naar klembord',
    'Could not find content of addon!' => 'Kan de inhoud van deze addon niet vinden!',
    'Could not find requested page.' => 'Kan de opgevraagde pagina niet vinden.',
    'Default' => 'Standaard',
    'Delete' => 'Verwijder',
    'Deny' => 'Weigeren',
    'Do you really want to perform this action?' => 'Weet u dit zeker?',
    'Edit' => 'Bewerk',
    'Error' => 'Fout',
    'Error while running your last action (Invalid request method).' => 'Fout bij het uitvoeren van uw laatste actie (Ongeldige request method).',
    'Error:' => 'Fout:',
    'Expand' => 'Uitklappen',
    'Export' => 'Exporteer',
    'Info:' => 'Informatie:',
    'Invalid request method!' => 'Ongeldige aanvraagmethode!',
    'It looks like you may have taken the wrong turn.' => 'U hebt misschien de verkeerde keuze gemaakt.',
    'Language' => 'Taal',
    'Loading...' => 'Laden...',
    'Login' => 'Log in',
    'Logo of {appName}' => 'Logo van {appName}',
    'Logout' => 'Uitloggen',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Module is niet op deze inhoud container ingeschakeld!',
    'My profile' => 'Mijn profiel',
    'New profile image' => 'Nieuwe profielfoto',
    'Next' => 'Volgende',
    'No error information given.' => 'Geen fout informatie beschikbaar.',
    'Oooops...' => 'Oeps...',
    'Open' => 'Open',
    'Please type at least 3 characters' => 'Typ tenminste 3 tekens',
    'Please type at least {count} characters' => 'Typ ten minste {count} tekens',
    'Powered by {name}' => 'Mogelijk gemaakt door {name}',
    'Profile dropdown' => 'Profiel keuzelijst',
    'Profile picture of {displayName}' => 'Profielafbeelding van {displayName}',
    'Save' => 'Opslaan',
    'Saved' => 'Opgeslagen',
    'Search' => 'Zoeken',
    'Select Me' => 'Klik op mij',
    'Show less' => 'Toon minder',
    'Show more' => 'Toon meer',
    'Some files could not be uploaded:' => 'Enkele bestanden zijn niet geüpload.',
    'Stop impersonation' => 'Nabootsing van identiteit stoppen',
    'Text could not be copied to clipboard' => 'De tekst kon niet worden gekopieerd naar het klembord.',
    'Text has been copied to clipboard' => 'De tekst is naar het klembord gekopieerd.',
    'The date has to be in the past.' => 'De datum moet in het verleden liggen.',
    'The file has been deleted.' => 'Het bestand is verwijderd.',
    'The requested resource could not be found.' => 'De gevraagde hulpbron kan niet worden gevonden.',
    'The space has been archived.' => 'De ruimte is gearchiveerd.',
    'The space has been unarchived.' => 'De ruimte is uit het archief gehaald.',
    'Time Zone' => 'Tijdzone',
    'Toggle comment menu' => 'Aan/uit commentaar menu',
    'Toggle panel menu' => 'Aan/uit paneelmenu',
    'Toggle post menu' => 'Aan/uit berichten menu',
    'Toggle stream entry menu' => 'Aan/uit nieuwsberichten menu',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Er zijn niet-opgeslagen wijzigingen, wilt u deze pagina echt verlaten?',
    'Unsubscribe' => 'Afmelden',
    'Upload' => 'Upload',
    'Upload file' => 'Upload bestand',
    'You are not allowed to run this action.' => 'U mag deze actie niet uitvoeren.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
];

==> humhub-1.15.0-beta.2.tar.gz: humhub-1.15.0-beta.2/protected/humhub/messages/nl/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>Zeker</strong> weten?',
    '<strong>Latest</strong> updates' => '<strong>Laatste</strong> updates',
    '<strong>Mail</strong> summary' => '<strong>E-mail</strong> samenvatting',
    'Actions' => 'Acties',
    'Add:' => 'Toevoegen:',
    'Administration' => 'Administratie',
    'All' => 'Allemaal',
    'Allow' => 'Toestaan',
    'Allow content from external source' => 'Inhoud van externe bron toestaan',
    'Always allow content from this provider!' => 'Sta altijd inhoud van deze provider toe!',
    'An error occurred while handling your last action. (Handler not found).' => 'Een fout deed zich voor bij het afhandelen van uw laatste actie. (Handler niet gevonden).',
    'An unexpected error occurred while loading the search result.' => 'Een onverwachte fout deed zich voor tijdens het laden van het zoekresultaat.',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => 'Een onverwachte fout deed zich voor; neem bij herhaling contact op met een beheerder van deze site.',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => 'Er is een onverwachte fout opgetreden. Controleer of uw bestand de toegestane uploadlimiet van {maxUploadSize} overschrijdt.',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => 'Een onbekende serverfout deed zich voor; neem bij herhaling contact op met een beheerder van deze site.',
    'Back' => 'Terug',
    'Back to dashboard' => 'Terug naar het dashboard',
    'Cancel' => 'Annuleren',
    'Choose language:' => 'Kies een taal:',
    'Close' => 'Sluiten',
    'Collapse' => 'Inklappen',
    'Confirm' => 'Bevestig',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => 'Content Addon bron moet een instantie van HActiveRecordContent of HActiveRecordContentAddon zijn!',
    'Copy to clipboard' => 'Kopieer naar klembord',
    'Could not find content of addon!' => 'Kan de inhoud van deze addon niet vinden!',
    'Could not find requested page.' => 'Kan de opgevraagde pagina niet vinden.',
    'Default' => 'Standaard',
    'Delete' => 'Verwijder',
    'Deny' => 'Weigeren',
    'Do you really want to perform this action?' => 'Weet u dit zeker?',
    'Do you want to enable content from \'{urlPrefix}\'?' => 'Wilt u inhoud van \'{urlPrefix}\' inschakelen?',
    'Edit' => 'Bewerk',
    'Error' => 'Fout',
    'Error while running your last action (Invalid request method).' => 'Fout bij het uitvoeren van uw laatste actie (Ongeldige request method).',
    'Error:' => 'Fout:',
    'Expand' => 'Uitklappen',
    'Export' => 'Exporteer',
    'Info:' => 'Informatie:',
    'Invalid request method!' => 'Ongeldige aanvraagmethode!',
    'It looks like you may have taken the wrong turn.' => 'U hebt misschien de verkeerde keuze gemaakt.',
    'Language' => 'Taal',
    'Loading...' => 'Laden...',
    'Login' => 'Log in',
    'Logo of {appName}' => 'Logo van {appName}',
    'Logout' => 'Uitloggen',
    'Menu' => 'Menu',
    'Module is not enabled on this content container!' => 'Module is niet op deze inhoud container ingeschakeld!',
    'My Profile' => 'Mijn profiel',
    'New profile image' => 'Nieuwe profielfoto',
    'Next' => 'Volgende',
    'No error information given.' => 'Geen fout informatie beschikbaar.',
    'Oooops...' => 'Oeps...',
    'Open' => 'Open',
    'Please type at least 3 characters' => 'Typ tenminste 3 tekens',
    'Please type at least {count} characters' => 'Typ ten minste {count} tekens',
    'Powered by {name}' => 'Mogelijk gemaakt door {name}',
    'Profile dropdown' => 'Profiel keuzelijst',
    'Profile picture of {displayName}' => 'Profielafbeelding van {displayName}',
    'Save' => 'Opslaan',
    'Saved' => 'Opgeslagen',
    'Search' => 'Zoeken',
    'Search...' => 'Zoeken...',
    'Select Me' => 'Klik op mij',
    'Settings' => 'Instellingen',
    'Show less' => 'Toon minder',
    'Show more' => 'Toon meer',
    'Some files could not be uploaded:' => 'Enkele bestanden zijn niet geüpload.',
    'Stop impersonation' => 'Nabootsing van identiteit stoppen',
    'Text could not be copied to clipboard' => 'De tekst kon niet worden gekopieerd naar het klembord.',
    'Text has been copied to clipboard' => 'De tekst is naar het klembord gekopieerd.',
    'The date has to be in the past.' => 'De datum moet in het verleden liggen.',
    'The file has been deleted.' => 'Het bestand is verwijderd.',
    'The requested resource could not be found.' => 'De gevraagde hulpbron kan niet worden gevonden.',
    'The space has been archived.' => 'De ruimte is gearchiveerd.',
    'The space has been unarchived.' => 'De ruimte is uit het archief gehaald.',
    'Time Zone' => 'Tijdzone',
    'Toggle comment menu' => 'Aan/uit commentaar menu',
    'Toggle panel menu' => 'Aan/uit paneelmenu',
    'Toggle post menu' => 'Aan/uit berichten menu',
    'Toggle stream entry menu' => 'Aan/uit nieuwsberichten menu',
    'Unsaved changes will be lost. Do you want to proceed?' => 'Er zijn niet-opgeslagen wijzigingen, wilt u deze pagina echt verlaten?',
    'Unsubscribe' => 'Afmelden',
    'Upload' => 'Upload',
    'Upload file' => 'Upload bestand',
    'You are not allowed to run this action.' => 'U mag deze actie niet uitvoeren.',
    'verify your upload_max_filesize and post_max_size php settings.' => 'Verifieer je upload_max_filesize en post_max_size php instellingen.',
    '{nFormatted}B' => '{nFormatted}B',
    '{nFormatted}K' => '{nFormatted}K',
    '{nFormatted}M' => '{nFormatted}M',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
];
